@@ -1,6 +1,12 @@
 #' doc_counts
 #' 
+#' @description
+#' Computes some basic document counts (see the 'Value' section below for
+#' details).
 #' 
+#' The function is vectorized by document, and scores are computed in parallel
+#' via OpenMP.  You can control the number of threads used with the
+#' \code{nthreads} parameter.
 #' 
 #' @details
 #' The function is essentially just \code{readability()} without the readability
@@ -8,6 +14,9 @@
 #' 
 #' @param s
 #' A character vector (vector of strings).
+#' @param nthreads
+#' Number of threads to use. By default it will use the total number of
+#' cores + hyperthreads.
 #' 
 #' @return
 #' A dataframe containing:
@@ -22,14 +31,16 @@
 #' }
 #' 
 #' @examples
-#' \dontrun{
 #' library(sylcount)
 #' a <- "I am the very model of a modern major general."
 #' b <- "I have information vegetable, animal, and mineral."
 #' 
-#' doc_counts(c(a, b))
-#' }
+#' doc_counts(c(a, b), nthreads=1)
 #' 
+#' @useDynLib sylcount R_corpus_summary
 #' @seealso \code{\link{readability}}
 #' @export
-doc_counts <- function(s) .Call(R_corpus_summary, s)
+doc_counts <- function(s, nthreads=sylcount.nthreads())
+{
+  .Call(R_corpus_summary, s, nthreads)
+}
