@@ -5,13 +5,12 @@
 #include <ctype.h>
 #include <stdbool.h>
 #include <string.h>
+
+#include "common.h"
 #include "hash.h"
 
 typedef struct sylcount sylcount_t;
 
-#define SYLCOUNT_MAX(a,b) ((a)<(b)?(b):(a))
-
-
 static inline bool isvowel(const char c)
 {
   return (c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u' || c == 'y' ||
